***************************
* File: enseignant.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\First Round\enseignant_ecole\enseignant.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "enseignant", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "enseignant", replace

**************************************************
***   Unique identifiers: ID
**************************************************
 egen ID=concat(  codecole cod_ensgt)
destring ID, replace
order  codecole cod_ensgt  ID
label var ID "identifiant unique"

**************************************************
***   Recode missing values
***************************************************
*    DECODE MISSING VALUES
# d ;
qui mvdecode   assoc , mv(
5=.d);
# d cr;

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist   an_ensgt-nature  aut_actv1- assoc{
	gen error01`v' = (present == 2 & `v'< . )
}

foreach v of varlist categ cadre retard {
	gen error02`v' = (position== 2 & `v'< . )
}
foreach v of varlist categ cadre retard {
	gen error03`v' = (position== 3 & `v'< . )
}
 foreach v of varlist categ cadre retard {
	gen error04`v' = (position== 4 & `v'< . )
}
foreach v of varlist categ cadre retard {
	gen error05`v' = (position== 5 & `v'< . )
} 
gen error06mis_dispt = ( maison == 2 &    mis_disp< . )
         
gen error07nb_avce = ( mod_paie == 1 &    nb_avce< . )
gen error08nb_avce = ( mod_paie == 2 &    nb_avce< . )
gen error09nb_avce = ( mod_paie == 4 &    nb_avce< . )
gen error10nb_avce = ( mod_paie == 5 &    nb_avce< . )

foreach v of varlist   dequi montant per_ind nature {
	gen error11`v' = (indemn  == 2 & `v'< . )
}


**************************************************
***  Identify illegal responses
**************************************************
log using "enseignant label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************
log using "enseignant grubbs", replace
preserve
global lab (		assoc	mod_paie	qui	maison	present	retard	non_paye	indemn	position	cadre	dipl_ac	ecol_prof	dipl_prof	dern_form	situat	origin	grandi	mis_disp	transp	per_etat	per_cisco	per_subv	per_parent	per_com	per_autre	per_sec	per_plui	per_ind	dequi	nature	aut_actv1	aut_actv2	aut_actv3)
global name (   nom_ensgt mod_nrt)
drop  $lab $name
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore

**************************************************
***   Reviewing errors and computing responses
**************************************************
replace sal_parent   =. if ID==10313224
replace per_parent  =. if ID==10313224
replace nb_avce =. if ID==30803231| ID==30803232| ID==21617211| ID==30405221 | ID==30803211| ID==11111211| ID==21617212| ID==71631222| ID==30405222| ID==30803233| ID==30803234| ID==71629221

drop error* 

**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\enseignant_ecole"
log using "enseignant codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\enseignant_ecole"
save "enseignant_cleaned_data.dta", replace
